// vim:syntax=javascript


// Low and High refer to Low and High potential (for a positive charge)
// If Low and High on a dimension are equal, assume the gradient is flat in
// that dimension.

class Field {
    private var _mc : MovieClip;

    private var _low_x : Number;
    private var _high_x : Number;
    private var _low_y : Number;
    private var _high_y : Number;
    private var _mag : Number;
    private var _screen_height : Number, _screen_width : Number;

    function get high_x () : Number {return _high_x;}
    function get high_y () : Number {return _high_y;}

    private var _is_horizontal : Boolean;
    private var _is_vertical : Boolean;
    private var _x_start : Number;
    private var _x_mag : Number;
    private var _f_x : Number;
    private var _y_start : Number;
    private var _y_mag : Number;
    private var _f_y : Number;

    function Field(mc : MovieClip, low_x : Number, high_x : Number, low_y : Number, high_y : Number, screen_width : Number, screen_height : Number, mag : Number) {
        _mc = mc;
        _low_x = low_x;
        _high_x = high_x;
        _low_y = low_y;
        _high_y = high_y;
        _mag = mag;
        _screen_height = screen_height;
        _screen_width = screen_width;

        reset();
    }

    function reset () : Void {
        _x_start = Math.min(_low_x, _high_x);
        _y_start = Math.min(_low_y, _high_y);
        var x_delta = _low_x - _high_x;
        var y_delta = _low_y - _high_y;
        _x_mag = Math.abs(x_delta);
        _y_mag = Math.abs(y_delta);
        _is_horizontal = (_x_mag != 0);
        _is_vertical = (_y_mag != 0);

        if (_is_horizontal) {
            _f_x = _mag/x_delta;
            _mc._width = _screen_height;
            _mc._height = _x_mag;
            if (x_delta < 0) {
                _mc._rotation = 270;
            } else {
                _mc._rotation = 90;
            }
            _mc._x = _low_x;
            _mc._y = 0;
        }
        if (_is_vertical) {
            _f_y = _mag/y_delta;
            _mc._rotation = 0;
            _mc._x = 0;
            _mc._y = _low_y;
            _mc._width = _screen_width;
            _mc._height = _y_mag;
        }

        //trace("x_start="+_x_start+", y_start="+_y_start);
        //trace("x_mag="+_x_mag+", y_mag="+_y_mag);

        // compromise solution: gnash does _xscale and _yscale in terms of the
        // original image size, while Adobe does it in terms of the _width and
        // _height already given
        if (x_delta < 0) {
            _mc._xscale = -_mc._xscale;
        }
        if (y_delta > 0) {
            _mc._yscale = -_mc._yscale;
        }

    }

    function update(low_x : Number, high_x : Number, low_y : Number, high_y : Number) {
        _low_x = low_x;
        _high_x = high_x;
        _low_y = low_y;
        _high_y = high_y;

        reset();
    }

    function computeForce(p : Particle) : Object {
        var fx = 0;
        var fy = 0;

        if (_is_horizontal && p.x > _x_start && (p.x - _x_start) < _x_mag) {
            fx = p.charge * _f_x;
            //trace(this+" in x range, fx="+fx);
        }
        if (_is_vertical && p.y > _y_start && (p.y - _y_start) < _y_mag) {
            fy = p.charge * _f_y;
            //trace(this+" in y range, fy="+fy);
        }

        return {fx:fx, fy:fy};
    }

    function toString() : String {
        return "Field ("+_high_x+","+_high_y+")-("+_low_x+","+_low_y+"), magnitude "+_mag;
    }

    function remove() {
        _mc.removeMovieClip();
    }
}
