// vim:syntax=javascript

class StatusBar extends MovieClip {
    var STATUS_WIDTH:Number = 400;
    var STATUS_HEIGHT:Number = 50;
    var mode_txt:TextField = null;
    var level_txt:TextField = null;
    var velocity_txt:TextField = null;
    var fields_txt:TextField = null;
    var message_txt:TextField = null;

    var last_level:Number = null;
    var last_mode:Boolean = null;
    var last_velocity:Number = null;
    var last_fields:Number = null;
    var last_maxfields:Number = null;

    var level_str:String = "Level #";
    var mode_str:String = "####";
    var velocity_str:String = "# m/s";
    var fields_str:String = "# Fields";
    var message_str:String = "### BEEEP ###";

    function setRunning(is_running:Boolean):Void {
        if (is_running == last_mode) {
            return;
        }
        last_mode = is_running;

        if (is_running) {
            mode_str = "Simulation Running";
        } else {
            mode_str = "Edit Mode";
        }
    }

    function setLevel(level:Number):Void {
        if (level == last_level) {
            return;
        }
        last_level = level;

        level_str = "Level " + level;
    }

    function setVelocity(velocity:Number):Void {
        if (velocity == last_velocity) {
            return;
        }
        last_velocity = velocity;

        var formatted : String = velocity.toString();
        if (formatted.length < 3) {
            formatted += ".0";
        }
        formatted = formatted.slice(0, Math.min(3,formatted.length));
        velocity_str = formatted + " m/s";
    }

    function setFields(fields:Number, maxfields:Number):Void {
        if (fields == last_fields && maxfields == last_maxfields) {
            return;
        }

        last_fields = fields;
        last_maxfields = maxfields;

        if (maxfields == 0) {
            fields_str = fields + " Field" + (fields==1?"":"s");
        } else {
            fields_str = fields + "/" + maxfields + " Field" + (maxfields==1?"":"s");
        }
    }
    
    function setMessage(message:String):Void {
        message_str = message;
    }

    function onLoad() {
        // background
        beginFill(0x9090C0);
        lineStyle(1, 0x000000);
        moveTo(0,0);
        lineTo(Stage.width-1,0);
        lineTo(Stage.width-1,50-1);
        lineTo(0,50-1);
        lineTo(0,0);
        endFill();

        // set up text strings

        var style_fmt:TextFormat = new TextFormat();
        style_fmt.font = "Vera";
        style_fmt.size = 15;
        var centered_fmt:TextFormat = new TextFormat();
        centered_fmt.font = "Vera";
        centered_fmt.size = 15;
        centered_fmt.align = "center";

        createTextField("mode_txt", getNextHighestDepth(), 235, 22, 400-5-235, 22);
        mode_txt.selectable = false;
        mode_txt.border = true;
        mode_txt.embedFonts = true;
        mode_txt.setNewTextFormat(centered_fmt);
        mode_txt.variable = this+".mode_str";

        createTextField("level_txt", getNextHighestDepth(), 5, 22, 70, 22);
        level_txt.selectable = false;
        level_txt.border = true;
        level_txt.embedFonts = true;
        level_txt.setNewTextFormat(style_fmt);
        level_txt.variable = this+".level_str";

        createTextField("velocity_txt", getNextHighestDepth(), 80, 22, 70, 22);
        velocity_txt.selectable = false;
        velocity_txt.border = true;
        velocity_txt.embedFonts = true;
        velocity_txt.setNewTextFormat(style_fmt);
        velocity_txt.variable = this+".velocity_str";

        createTextField("fields_txt", getNextHighestDepth(), 155, 22, 75, 22);
        fields_txt.selectable = false;
        fields_txt.border = true;
        fields_txt.embedFonts = true;
        fields_txt.setNewTextFormat(style_fmt);
        fields_txt.variable = this+".fields_str";

        createTextField("message_txt", getNextHighestDepth(), 5, 0, 390, 22);
        message_txt.selectable = false;
        message_txt.border = false;
        message_txt.embedFonts = true;
        message_txt.setNewTextFormat(style_fmt);
        message_txt.variable = this+".message_str";
    }
}
